@@ -1,17 +1,3 @@
-#' @title htmlwidget for flextable
-#'
-#' @description htmlwidget for flextable. This function is deprecated.
-#'
-#' @param x \code{flextable} object
-#' @param ... Unused arguments
-#'
-#' @export
-tabwid <- function(x, ...) {
-
-  .Deprecated(msg = "tabwid is no more required as flextable objects have their own knit_print method now.")
-  knit_print(x)
-}
-
 html_str <- function( x ){
   UseMethod("html_str")
 }
@@ -22,14 +8,19 @@ html_str.regulartable <- function( x ){
   dims <- dim(x)
 
   out <- "<table>"
-  if( !is.null(x$header) ){
+
+  if( nrow_part(x, "header") > 0 ){
     tmp <- format(x$header, type = "html", header = TRUE)
     out = paste0(out, "<thead>", tmp, "</thead>" )
   }
-  if( !is.null(x$body) ){
+  if( nrow_part(x, "body") > 0 ){
     tmp <- format(x$body, type = "html", header = FALSE)
     out = paste0(out, "<tbody>", tmp, "</tbody>" )
   }
+  if( nrow_part(x, "footer") > 0 ){
+    tmp <- format(x$footer, type = "html", header = FALSE)
+    out = paste0(out, "<tfoot>", tmp, "</tfoot>" )
+  }
 
   out = paste0(out,  "</table>" )
   out
