@@ -7,7 +7,7 @@
 #' @param pr_t object(s) of class \code{fp_text}
 #' @param pr_p object(s) of class \code{fp_par}
 #' @param pr_c object(s) of class \code{fp_cell}
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header' or 'footer')
 #' @importFrom stats terms update
 #' @examples
 #' library(officer)
@@ -25,11 +25,11 @@
 style <- function(x, i = NULL, j = NULL,
                   pr_t = NULL, pr_p = NULL, pr_c = NULL, part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
     args <- list()
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       args$x <- x
       args$i <- i
       args$j <- j
@@ -42,6 +42,9 @@ style <- function(x, i = NULL, j = NULL,
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -62,22 +65,25 @@ style <- function(x, i = NULL, j = NULL,
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param bg color to use as background color
 #' @examples
 #' ft <- flextable(mtcars)
 #' ft <- bg(ft, bg = "#DDDDDD", part = "header")
 bg <- function(x, i = NULL, j = NULL, bg, part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- bg(x = x, i = i, j = j, bg = bg, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -101,22 +107,25 @@ bg <- function(x, i = NULL, j = NULL, bg, part = "body" ){
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param bold boolean value
 #' @examples
 #' ft <- flextable(mtcars)
 #' ft <- bold(ft, bold = TRUE, part = "header")
 bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- bold(x = x, i = i, j = j, bold = bold, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -138,22 +147,25 @@ bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body" ){
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param size integer value (points)
 #' @examples
 #' ft <- flextable(mtcars)
 #' ft <- fontsize(ft, size = 14, part = "header")
 fontsize <- function(x, i = NULL, j = NULL, size = 11, part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- fontsize(x = x, i = i, j = j, size = size, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -175,22 +187,25 @@ fontsize <- function(x, i = NULL, j = NULL, size = 11, part = "body" ){
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param italic boolean value
 #' @examples
 #' ft <- flextable(mtcars)
 #' ft <- italic(ft, italic = TRUE, part = "header")
 italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- italic(x = x, i = i, j = j, italic = italic, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -211,22 +226,25 @@ italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body" ){
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param color color to use as font color
 #' @examples
 #' ft <- flextable(mtcars)
 #' ft <- color(ft, color = "orange", part = "header")
 color <- function(x, i = NULL, j = NULL, color, part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- color(x = x, i = i, j = j, color = color, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -250,7 +268,7 @@ color <- function(x, i = NULL, j = NULL, color, part = "body" ){
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param padding padding (shortcut for top, bottom, left and right)
 #' @param padding.top padding top
 #' @param padding.bottom padding bottom
@@ -264,7 +282,7 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
                     padding.left = NULL, padding.right = NULL,
                     part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( !is.null(padding) ){
     if( is.null( padding.top) ) padding.top <- padding
@@ -273,7 +291,7 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
     if( is.null( padding.right) ) padding.right <- padding
   }
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- padding(x = x, i = i, j = j,
                    padding.top = padding.top, padding.bottom = padding.bottom,
                    padding.left = padding.left, padding.right = padding.right,
@@ -282,6 +300,9 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -312,7 +333,7 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param align text alignment - a single character value, expected value
 #' is one of 'left', 'right', 'center', 'justify'.
 #' @examples
@@ -321,15 +342,18 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
 align <- function(x, i = NULL, j = NULL, align = "left",
                     part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- align(x = x, i = i, j = j, align = align, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -354,7 +378,7 @@ align <- function(x, i = NULL, j = NULL, align = "left",
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param border border (shortcut for top, bottom, left and right)
 #' @param border.top border top
 #' @param border.bottom border bottom
@@ -369,7 +393,7 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
                    border.left = NULL, border.right = NULL,
                    part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( !is.null(border) ){
     if( is.null( border.top) ) border.top <- border
@@ -379,7 +403,7 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
   }
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- border(x = x, i = i, j = j,
                   border.top = border.top, border.bottom = border.bottom,
                   border.left = border.left, border.right = border.right,
@@ -388,6 +412,11 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
     return(x)
   }
 
+  # if( "footer" %in% part ) browser()
+
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
@@ -417,7 +446,7 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header')
+#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param rotation one of "lrtb", "tbrl", "btlr"
 #' @param align one of "center" or "top" or "bottom"
 #' @examples
@@ -425,15 +454,18 @@ border <- function(x, i = NULL, j = NULL, border = NULL,
 #' ft <- rotate(ft, rotation = "lrtb", align = "top", part = "header")
 rotate <- function(x, i = NULL, j = NULL, rotation, align = "center", part = "body" ){
 
-  part <- match.arg(part, c("all", "body", "header"), several.ok = FALSE )
+  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
   if( part == "all" ){
-    for( p in c("header", "body") ){
+    for( p in c("header", "body", "footer") ){
       x <- rotate(x = x, i = i, j = j, rotation = rotation, part = p)
     }
     return(x)
   }
 
+  if( nrow_part(x, part) < 1 )
+    return(x)
+
   check_formula_i_and_part(i, part)
   i <- get_rows_id(x[[part]], i )
   j <- get_columns_id(x[[part]], j )
